pygeodesy.deprecated.consterns.Elliperim

Package pygeodesy :: Package deprecated :: Module consterns :: Class Elliperim |
[frames] | no frames]

# Class Elliperim

    object --+
             |
            Elliperim

DEPRECATED on 2026.02.06, use class Ellipse.

Instance Methods
AGM(self, a, b, **unused) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeterAGM}. |
Arc43(self, a, b) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeter4Arc3}. |
E2k(self, a, b) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeter2k}. |
GK(self, a, b) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeterGK}. |
HG(self, a, b, **unused) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeterHGK}. |
R2(self, a, b) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeter2R}. |
e2k(self, a, b, **unused) DEPRECATED on 2026.02.12, use property Ellipse{C(a, b).perimeter2k_}. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`